// mpr.h

#ifndef MPR_H
#define MPR_H

#define WGS84  (23)

typedef struct {
  unsigned long marker;
  unsigned long dummy[2];
  unsigned long tile_width;
  unsigned long tile_height;
  unsigned long tiles_x;
  unsigned long tiles_y;
} __attribute__((packed)) mph_header_t;

// rgb color entry from mph file
typedef struct {
  unsigned char r,g,b;
} color_t;

typedef struct {
  /* other info */
  char filename[128];
  char cachedir[128];
  char basename[32];
  int zoom;
  double rescale;
  int min_northing, min_easting;
  int max_northing, max_easting;

  /* info from the mph file: */
  char name[32];
  unsigned short width, height;  // size in tiles
  unsigned long scale[2];

  // geographic information
  unsigned short zone;
  char band;

  // offset utm/map in meters
  long x_offset, y_offset;

  // size of a pixel in dm (1/10 m)
  unsigned short dm_per_pixel;

  mph_header_t mph_header;
  color_t *colors;
} map_info_t;


/* exported functions */
int mpr_load_header(char *name, map_info_t *map_info);
void LLtoUTM(int ReferenceEllipsoid, const double Lat, const double Long,
             long *UTMNorthing, long *UTMEasting, unsigned short *UTMZone, 
	     char* UTMBand);
int mpr_get(char *path, char *name, map_info_t *map_info, int tile_no);
int mpr_utm2map(map_info_t *map_info, 
		int nothing, int easting, short zone, char band, 
		int *x, int *y);
int mpr_map2utm(map_info_t *map_info, 
		int x, int y,
		int *northing, int *easting, short *zone, char *band);

#endif // MPR_H
